@@ -138,11 +138,10 @@ use strict;
 use vars qw($VERSION); 
 
 ### System modules:
-use IO::Scalar;
 use Carp;
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.419";
+$VERSION = "5.421";
 
 
 #------------------------------
@@ -214,8 +213,9 @@ repeated read() calls; your subclass might wish to override this.
 sub as_string {
     my $self = shift;
     my $str = '';
-    my $out = new IO::Scalar \$str;
-    $self->print($out);
+    my $fh = IO::File->new(\$str, '>:') or croak("Cannot open in-memory file: $!");
+    $self->print($fh);
+    close($fh);
     return $str;
 }
 *data = \&as_string;         ### silenty invoke preferred usage
@@ -328,7 +328,7 @@ sub print {
     my $nread;
 
     ### Get output filehandle, and ensure that it's a printable object:
-    $fh = IO::Wrap::wraphandle($fh || select);
+    $fh ||= select;
 
     ### Write it:
     my $buf = '';
@@ -365,8 +365,8 @@ The following built-in classes are provided:
    class:               data in:        returns:    
    --------------------------------------------------------
    MIME::Body::File     disk file       IO::Handle   
-   MIME::Body::Scalar   scalar          IO::Scalar  
-   MIME::Body::InCore   scalar array    IO::ScalarArray
+   MIME::Body::Scalar   scalar          IO::Handle   
+   MIME::Body::InCore   scalar array    IO::Handle   
 
 =cut
 
@@ -377,8 +377,8 @@ package MIME::Body::File;
 
 =head2 MIME::Body::File
 
-A body class that stores the data in a disk file.  
-The I/O handle is a wrapped filehandle.  Invoke the constructor as:
+A body class that stores the data in a disk file.  Invoke the
+constructor as:
 
     $body = new MIME::Body::File "/path/to/file";
 
@@ -403,11 +403,10 @@ use vars qw(@ISA);
 use strict;
 
 ### System modules:
-require FileHandle;
+use IO::File;
 
 ### Kit modules:
 use MIME::Tools qw(whine);
-use IO::Wrap;
 
 @ISA = qw(MIME::Body);
 
@@ -426,19 +425,18 @@ sub init {
 #------------------------------
 sub open {
     my ($self, $mode) = @_;
-    my $IO;
+
     my $path = $self->path;
-    if ($mode eq 'w') {          ### writing
-	$IO = FileHandle->new(">$path") || die "write-open $path: $!";
-    }
-    elsif ($mode eq 'r') {       ### reading
-	$IO = FileHandle->new("<$path") || die "read-open $path: $!";
-    }
-    else {  
+
+    if( $mode ne 'r' && $mode ne 'w' ) {
 	die "bad mode: '$mode'";
     }
-    binmode($IO) if $self->binmode;        ### set binary read/write mode?
-    return (IO::Wrap::wraphandle($IO));    ### wrap if old FileHandle class
+
+    my $IO = IO::File->new($path, $mode) || die "MIME::Body::File->open $path: $!";
+
+    $IO->binmode() if $self->binmode;
+
+    return $IO;
 }
 
 #------------------------------
@@ -482,16 +480,11 @@ elements of that array together:
                                     "Line 2\n",
                                     "Line 3"];
 
-Uses B<IO::Scalar> as the I/O handle.
-
 =cut
 
 use vars qw(@ISA);
 use strict;
 
-require FileHandle;
-
-use IO::Scalar;
 use Carp;
 
 @ISA = qw(MIME::Body);
@@ -520,7 +513,16 @@ sub as_string {
 sub open {
     my ($self, $mode) = @_;
     $self->{MBS_Data} = '' if ($mode eq 'w');        ### writing
-    return new IO::Scalar \($self->{MBS_Data});
+
+    if ($mode eq 'w') {
+	    $mode = '>:';
+    } elsif ($mode eq 'r') {
+	    $mode = '<:';
+    } else {
+	    die "bad mode: $mode";
+    }
+
+    return IO::File->new(\($self->{MBS_Data}), $mode);
 }
 
 
@@ -543,7 +545,7 @@ Invoke the constructor as:
 A simple scalar argument sets the body to that value, exactly as though
 you'd opened for the body for writing, written the value, 
 and closed the body again:
-    
+
     $body = new MIME::Body::InCore "Line 1\nLine 2\nLine 3";
 
 A single array reference sets the body to the concatenation of all
@@ -553,19 +555,14 @@ scalars that it holds:
                                     "Line 2\n",
                                     "Line 3"];
 
-Uses B<IO::ScalarArray> as the I/O handle.
-
 =cut
 
 use vars qw(@ISA);
 use strict;
 
-require FileHandle;
-
-use IO::ScalarArray;
 use Carp;
 
-@ISA = qw(MIME::Body);
+@ISA = qw(MIME::Body::Scalar);
 
 
 #------------------------------
@@ -574,16 +571,16 @@ use Carp;
 sub init {
     my ($self, $data) = @_;
     if (!defined($data)) {  ### nothing
-	$self->{MBC_Data} = [];
+	$self->{MBS_Data} = '';
     }
     elsif (!ref($data)) {   ### simple scalar
-	$self->{MBC_Data} = [ $data ];
+	$self->{MBS_Data} = $data;
     }
     elsif (ref($data) eq 'SCALAR') {
-	$self->{MBC_Data} = [ $$data ];
+	$self->{MBS_Data} = $$data;
     }
     elsif (ref($data) eq 'ARRAY') {
-	$self->{MBC_Data} = $data;
+	$self->{MBS_Data} = join('', @$data);
     }
     else {
 	croak "I can't handle DATA which is a ".ref($data)."\n";
@@ -591,24 +588,6 @@ sub init {
     $self;
 }
 
-#------------------------------
-# as_string
-#------------------------------
-sub as_string {
-    my $self = shift;
-    return join '', @{$self->{MBC_Data}};
-}
-
-#------------------------------
-# open READWRITE
-#------------------------------
-sub open {
-    my ($self, $mode) = @_;
-    $self->{MBC_Data} = [] if ($mode eq 'w');        ### writing
-    return new IO::ScalarArray $self->{MBC_Data};
-}
-
-
 1;
 __END__
 
@@ -650,10 +629,10 @@ The default inherited method I<will probably not suffice> for these:
 
 =head1 NOTES
 
-One reason I didn't just use FileHandle or IO::Handle objects for message
-bodies was that I wanted a "body" object to be a form of completely
-encapsulated program-persistent storage; that is, I wanted users
-to be able to write code like this...
+One reason I didn't just use IO::Handle objects for message bodies was
+that I wanted a "body" object to be a form of completely encapsulated
+program-persistent storage; that is, I wanted users to be able to write
+code like this...
 
    ### Get body handle from this MIME message, and read its data:
    $body = $entity->bodyhandle;
@@ -686,14 +665,6 @@ it and/or modify it under the same terms as Perl itself.
 Thanks to Achim Bohnet for suggesting that MIME::Parser not be restricted
 to the use of FileHandles.
 
-
-
-=head1 VERSION
-
-$Revision: 1.12 $ $Date: 2005/12/22 14:56:59 $
-
-=cut
-
 #------------------------------
 1;
 
