@@ -30,8 +30,10 @@ of course).
 
 When B<encoding>, the input is read 45 bytes at a time: this ensures
 that the output lines are not too long.   We chose 45 since it is
-a multiple of 3 and produces lines under 76 characters, as RFC-1521 
-specifies.
+a multiple of 3 and produces lines under 76 characters, as RFC 2045
+specifies:
+    The encoded output stream must be represented in lines of no more
+    than 76 characters each.
 
 =back
 
@@ -43,11 +45,6 @@ Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
 All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
 
-
-=head1 VERSION
-
-$Revision: 1.10 $ $Date: 2006/03/17 21:03:23 $
-
 =cut
 
 use vars qw(@ISA $VERSION);
@@ -58,7 +55,7 @@ use MIME::Tools qw(debug);
 @ISA = qw(MIME::Decoder);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.420";
+$VERSION = "5.421";
 
 ### How many bytes to encode at a time (must be a multiple of 3, and
 ### less than (76 * 0.75)!
