@@ -37,7 +37,7 @@ Ready?  Ok...
 A subclass of B<Mail::Internet>.
 
 This package provides a class for representing MIME message entities,
-as specified in RFC 1521, I<Multipurpose Internet Mail Extensions>.
+as specified in RFCs 2045, 2046, 2047, 2048 and 2049.
 
 
 =head1 EXAMPLES
@@ -223,7 +223,6 @@ use vars qw(@ISA $VERSION);
 use strict;
 
 ### System modules:
-use FileHandle;
 use Carp;
 
 ### Other modules:
@@ -235,8 +234,6 @@ use MIME::Tools qw(:config :msgs :utils);
 use MIME::Head;
 use MIME::Body;
 use MIME::Decoder;
-use IO::ScalarArray;
-use IO::Wrap;
 use IO::Lines;
 
 @ISA = qw(Mail::Internet);
@@ -249,7 +246,7 @@ use IO::Lines;
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.418";
+$VERSION = "5.421";
 
 ### Boundary counter:
 my $BCount = 0;
@@ -296,7 +293,10 @@ sub known_field {
 # This is used both internally and by MIME::ParserBase, but it is NOT in
 # the public interface!  Do not use it!
 #
-# We generate one containing a "=_", as RFC1521 suggests.
+# We generate one containing a "=_", as RFC2045 suggests:
+#    A good strategy is to choose a boundary that includes a character
+#    sequence such as "=_" which can never appear in a quoted-printable
+#    body.  See the definition of multipart messages in RFC 2046.
 #
 sub make_boundary {
     return "----------=_".scalar(time)."-$$-".$BCount++;
@@ -466,11 +466,11 @@ field (and it sort of looks like one too).
 
 =item Boundary
 
-I<Multipart entities only. Optional.>  
-The boundary string.  As per RFC-1521, it must consist only
+I<Multipart entities only. Optional.>
+The boundary string.  As per RFC-2046, it must consist only
 of the characters C<[0-9a-zA-Z'()+_,-./:=?]> and space (you'll be
 warned, and your boundary will be ignored, if this is not the case).
-If you omit this, a random string will be chosen... which is probably 
+If you omit this, a random string will be chosen... which is probably
 safer.
 
 =item Charset
@@ -535,10 +535,10 @@ The default is true.  (NB: look at how C<attach()> uses it.)
 
 =item Type
 
-I<Optional.>  
-The basic content-type (C<"text/plain">, etc.). 
-If you don't specify it, it defaults to C<"text/plain"> 
-as per RFC-1521.  I<Do yourself a favor: put it in.>
+I<Optional.>
+The basic content-type (C<"text/plain">, etc.).
+If you don't specify it, it defaults to C<"text/plain">
+as per RFC 2045.  I<Do yourself a favor: put it in.>
 
 =back
 
@@ -651,8 +651,8 @@ sub build {
 
     ### Add the X-Mailer field, if top level (use default value if not given):
     $top and $head->replace('X-Mailer', 
-			    "MIME-tools ".(0+MIME::Tools->version).
-			    " (Entity "  .(0+$VERSION).")"); 
+			    "MIME-tools ".(MIME::Tools->version).
+			    " (Entity "  .($VERSION).")"); 
 	
     ### Add remaining user-specified fields, if any:
     while (@paramlist) {
@@ -686,7 +686,7 @@ external data in bodyhandles is I<not> copied to new files!
 Changing the data in one entity's data file, or purging that entity, 
 I<will> affect its duplicate.  Entities with in-core data probably need
 not worry.
-
+'
 =cut
 
 sub dup {
@@ -755,16 +755,17 @@ or raw data (via read()).
 =cut
 
 sub body {
-    my ($self, $value) = @_;
-    if (@_ > 1) {      ### setting body line(s)...
-	croak "you cannot use body() to set the encoded contents\n";
-    }
-    else {             ### getting body lines...
-	my $lines = [];
-	my $lh = IO::Lines->new($lines);
-	$self->print_body($lh);
-	return $lines;
-    }
+	my ($self, $value) = @_;
+	if (@_ > 1) {      ### setting body line(s)...
+		croak "you cannot use body() to set the encoded contents\n";
+	}
+	else {             ### getting body lines...
+		my $output = '';
+		my $fh = IO::File->new(\$output, '>:') or croak("Cannot open in-memory file: $!");
+		$self->print_body($fh);
+		close($fh);
+		return split("\n", $output);
+	}
 }
 
 #------------------------------
@@ -1371,9 +1372,9 @@ sub sign {
 	$sig = (ref($sig) ? join('', @$sig) : $sig);
     }
     elsif ($params{File}) {                      ### file contents
-	CORE::open SIG, $params{File} or croak "can't open $params{File}: $!";
-	$sig = join('', SIG->getlines);
-	close SIG or croak "can't close $params{File}: $!";
+	my $fh = IO::File->new( $params{File} ) or croak "can't open $params{File}: $!";
+	$sig = join('', $fh->getlines);
+	$fh->close or croak "can't close $params{File}: $!";
     }
     else {
 	croak "no signature given!";
@@ -1445,8 +1446,8 @@ sub suggest_encoding {
 	$self->bodyhandle || return ($self->parts ? 'binary' : '7bit');
 	my ($IO, $unclean);
 	if ($IO = $self->bodyhandle->open("r")) {
-
-	    ### Scan message for 7bit-cleanliness:
+	    ### Scan message for 7bit-cleanliness
+	    local $_;
 	    while (defined($_ = $IO->getline)) {
 		last if ($unclean = ((length($_) > 999) or /[\200-\377]/));
 	    }
@@ -1743,8 +1744,7 @@ sub print {
     my ($self, $out) = @_;
     $out = select if @_ < 2;
     $out = Symbol::qualify($out,scalar(caller)) unless ref($out);
-    $out = wraphandle($out);             ### get a printable output
-    
+
     $self->print_header($out);   ### the header
     $out->print("\n");
     $self->print_body($out);     ### the "stuff after the header"
@@ -1785,7 +1785,7 @@ filehandle is given: this may lead to confusion.
 
 sub print_body {
     my ($self, $out) = @_;
-    $out = wraphandle($out || select);             ### get a printable output
+    $out ||= select;
     my ($type) = split '/', lc($self->mime_type);  ### handle by MIME type
 
     ### Multipart...
@@ -1794,7 +1794,7 @@ sub print_body {
 
 	### Preamble:
 	my $preamble = join('', @{ $self->preamble || $DefPreamble });
-	$out->print("$preamble\n") if ($preamble ne '');
+	$out->print("$preamble\n") if ($preamble ne '' or $self->preamble);
 
 	### Parts:
 	my $part;
@@ -1844,16 +1844,22 @@ sub print_body {
 #
 sub print_bodyhandle {
     my ($self, $out) = @_;
-    $out = wraphandle($out || select);             ### get a printable output
+    $out ||= select;
 
-    ### Get the encoding, defaulting to "binary" if unsupported:
-    my $encoding = ($self->head->mime_encoding || 'binary');
-    my $decoder = best MIME::Decoder $encoding;
-    $decoder->head($self->head);      ### associate with head, if any
-
-    ### Output the body:
     my $IO = $self->open("r")     || die "open body: $!";
-    $decoder->encode($IO, $out, textual_type($self->head->mime_type) ? 1 : 0)   || die "encoding failed\n";
+    if ( $self->bodyhandle->is_encoded ) {
+      ### Transparent mode: data is already encoded, so no
+      ### need to encode it again
+      my $buf;
+      $out->print($buf) while ($IO->read($buf, 2048));
+    } else {
+      ### Get the encoding, defaulting to "binary" if unsupported:
+      my $encoding = ($self->head->mime_encoding || 'binary');
+      my $decoder = best MIME::Decoder $encoding;
+      $decoder->head($self->head);      ### associate with head, if any
+      $decoder->encode($IO, $out, textual_type($self->head->mime_type) ? 1 : 0)   || return error "encoding failed";
+    }
+
     $IO->close;
     1;
 }
@@ -1882,9 +1888,12 @@ You can also use C<as_string()>.
 =cut
 
 sub stringify {
-    my @arr = ();
-    shift->print(new IO::ScalarArray \@arr);
-    join("", @arr);
+	my ($self) = @_;
+	my $output = '';
+	my $fh = IO::File->new( \$output, '>:' ) or croak("Cannot open in-memory file: $!");
+	$self->print($fh);
+	$fh->close;
+	return $output;
 }
 
 sub as_string { shift->stringify };      ### silent BC
@@ -1910,25 +1919,16 @@ singlepart message (like a "text/plain"), use C<bodyhandle()> instead:
 =cut
 
 sub stringify_body {
-    my @arr = ();
-    shift->print_body(new IO::ScalarArray \@arr);
-    join("", @arr);
+	my ($self) = @_;
+	my $output = '';
+	my $fh = IO::File->new( \$output, '>:' ) or croak("Cannot open in-memory file: $!");
+	$self->print_body($fh);
+	$fh->close;
+	return $output;
 }
+
 sub body_as_string { shift->stringify_body }
 
-#------------------------------
-#
-# stringify_bodyhandle
-#
-# Instance method, unpublicized.  Stringify just the bodyhandle.
-
-sub stringify_bodyhandle {
-    my @arr = ();
-    shift->print_bodyhandle(new IO::ScalarArray \@arr);
-    join("", @arr);
-}
-sub bodyhandle_as_string { shift->stringify_bodyhandle }
-
 #------------------------------
 
 =item stringify_header 
@@ -1945,9 +1945,8 @@ sub stringify_header {
 sub header_as_string { shift->stringify_header }
 
 
-
-__END__
 1;
+__END__
   
 #------------------------------
 
@@ -2061,15 +2060,6 @@ As an array of lines, ready for sending.
 B<MIME::Entity:> 
 As an array of lines, ready for sending.
 
-
-=item If an entity has a body, does it have a soul as well?
-
-The soul does not exist in a corporeal sense, the way the body does; 
-it is not a solid [Perl] object.  Rather, it is a virtual object
-which is only visible when you print() an entity to a file... in other
-words, the "soul" it is all that is left after the body is DESTROY'ed.  
-
-
 =item What's the best way to get at the body data?
 
 B<Mail::Internet:> 
@@ -2193,30 +2183,30 @@ In multipart messages, the I<"preamble"> is the portion that precedes
 the first encapsulation boundary, and the I<"epilogue"> is the portion
 that follows the last encapsulation boundary.
 
-According to RFC-1521:
+According to RFC 2046:
 
-    There appears to be room for additional information prior 
-    to the first encapsulation boundary and following the final 
+    There appears to be room for additional information prior
+    to the first encapsulation boundary and following the final
     boundary.  These areas should generally be left blank, and
-    implementations must ignore anything that appears before the 
+    implementations must ignore anything that appears before the
     first boundary or after the last one.
 
-    NOTE: These "preamble" and "epilogue" areas are generally 
-    not used because of the lack of proper typing of these parts 
-    and the lack of clear semantics for handling these areas at 
-    gateways, particularly X.400 gateways.  However, rather than 
-    leaving the preamble area blank, many MIME implementations 
-    have found this to be a convenient place to insert an 
-    explanatory note for recipients who read the message with 
-    pre-MIME software, since such notes will be ignored by 
+    NOTE: These "preamble" and "epilogue" areas are generally
+    not used because of the lack of proper typing of these parts
+    and the lack of clear semantics for handling these areas at
+    gateways, particularly X.400 gateways.  However, rather than
+    leaving the preamble area blank, many MIME implementations
+    have found this to be a convenient place to insert an
+    explanatory note for recipients who read the message with
+    pre-MIME software, since such notes will be ignored by
     MIME-compliant software.
 
-In the world of standards-and-practices, that's the standard.  
-Now for the practice: 
+In the world of standards-and-practices, that's the standard.
+Now for the practice:
 
 I<Some "MIME" mailers may incorrectly put a "part" in the preamble>.
 Since we have to parse over the stuff I<anyway>, in the future I
-I<may> allow the parser option of creating special MIME::Entity objects 
+I<may> allow the parser option of creating special MIME::Entity objects
 for the preamble and epilogue, with bogus MIME::Head objects.
 
 For now, though, we're MIME-compliant, so I probably won't change
@@ -2233,12 +2223,4 @@ David F. Skoll (dfs@roaringpenguin.com) http://www.roaringpenguin.com
 All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
 
-
-=head1 VERSION
-
-$Revision: 1.12 $ $Date: 2005/09/28 13:59:20 $
-
 =cut
-
-#------------------------------
-1;
